@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
 """Event loop."""
-from __future__ import absolute_import, unicode_literals
 
 from .hub import Hub, get_event_loop, set_event_loop
 
