@@ -1,20 +1,19 @@
-"""
-kombu.transport.memory
-======================
+"""In-memory transport."""
 
-In-memory transport.
-
-"""
-from __future__ import absolute_import
-
-from Queue import Queue
+from queue import Queue
 
+from . import base
 from . import virtual
+from collections import defaultdict
 
 
 class Channel(virtual.Channel):
+    """In-memory Channel."""
+
+    events = defaultdict(set)
     queues = {}
     do_restore = False
+    supports_fanout = True
 
     def _has_queue(self, queue, **kwargs):
         return queue in self.queues
@@ -31,13 +30,20 @@ class Channel(virtual.Channel):
             self.queues[queue] = Queue()
         return self.queues[queue]
 
+    def _queue_bind(self, *args):
+        pass
+
+    def _put_fanout(self, exchange, message, routing_key=None, **kwargs):
+        for queue in self._lookup(exchange, routing_key):
+            self._queue_for(queue).put(message)
+
     def _put(self, queue, message, **kwargs):
         self._queue_for(queue).put(message)
 
     def _size(self, queue):
         return self._queue_for(queue).qsize()
 
-    def _delete(self, queue, *args):
+    def _delete(self, queue, *args, **kwargs):
         self.queues.pop(queue, None)
 
     def _purge(self, queue):
@@ -46,16 +52,26 @@ class Channel(virtual.Channel):
         q.queue.clear()
         return size
 
+    def close(self):
+        super().close()
+        for queue in self.queues.values():
+            queue.empty()
+        self.queues = {}
+
     def after_reply_message_received(self, queue):
         pass
 
 
 class Transport(virtual.Transport):
+    """In-memory Transport."""
+
     Channel = Channel
 
     #: memory backend state is global.
     state = virtual.BrokerState()
 
+    implements = base.Transport.implements
+
     driver_type = 'memory'
     driver_name = 'memory'
 
