@@ -3,9 +3,9 @@
 :copyright: (c) 2010 - 2013 by Flavio Percoco Premoli.
 :license: BSD, see LICENSE for more details.
 """
-from __future__ import absolute_import, unicode_literals
 
 import datetime
+from queue import Empty
 
 import pymongo
 from pymongo import errors
@@ -13,7 +13,6 @@ from pymongo import MongoClient, uri_parser
 from pymongo.cursor import CursorType
 
 from kombu.exceptions import VersionMismatch
-from kombu.five import Empty, string_t
 from kombu.utils.compat import _detect_environment
 from kombu.utils.encoding import bytes_to_str
 from kombu.utils.json import loads, dumps
@@ -32,7 +31,7 @@ Kombu requires MongoDB version 2.2+ (server is {0}) for TTL indexes support\
 """
 
 
-class BroadcastCursor(object):
+class BroadcastCursor:
     """Cursor for broadcast queues."""
 
     def __init__(self, cursor):
@@ -112,7 +111,7 @@ class Channel(virtual.Channel):
     ))
 
     def __init__(self, *vargs, **kwargs):
-        super(Channel, self).__init__(*vargs, **kwargs)
+        super().__init__(*vargs, **kwargs)
 
         self._broadcast_cursors = {}
 
@@ -155,7 +154,7 @@ class Channel(virtual.Channel):
         # Do not calculate actual queue size if requested
         # for performance considerations
         if not self.calc_queue_size:
-            return super(Channel, self)._size(queue)
+            return super()._size(queue)
 
         if queue in self._fanout_queues:
             return self._get_broadcast_cursor(queue).get_size()
@@ -225,7 +224,7 @@ class Channel(virtual.Channel):
         if self.ttl:
             self.queues.remove({'_id': queue})
 
-        super(Channel, self).queue_delete(queue, **kwargs)
+        super().queue_delete(queue, **kwargs)
 
         if queue in self._fanout_queues:
             try:
@@ -407,7 +406,7 @@ class Channel(virtual.Channel):
         Note:
             `queue` must be either queue name or options itself.
         """
-        if isinstance(queue, string_t):
+        if isinstance(queue, str):
             doc = self.queues.find_one({'_id': queue})
 
             if not doc:
