@@ -3,14 +3,13 @@
 Implementations of the standard exchanges defined
 by the AMQ protocol  (excluding the `headers` exchange).
 """
-from __future__ import absolute_import, unicode_literals
 
 import re
 
 from kombu.utils.text import escape_regex
 
 
-class ExchangeType(object):
+class ExchangeType:
     """Base class for exchanges.
 
     Implements the specifics for an exchange type.
