@@ -3,7 +3,7 @@ import pickle
 from heapq import heappush
 from time import time
 
-from case import Mock
+from unittest.mock import Mock
 
 from kombu.clocks import LamportClock, timetuple
 
