@@ -1,7 +1,7 @@
 import logging
 import sys
 
-from case import ANY, Mock, patch
+from unittest.mock import ANY, Mock, patch
 
 from kombu.log import (
     get_logger,
