@@ -1,7 +1,7 @@
 import pytest
 import sys
 
-from case import Mock, patch
+from unittest.mock import Mock, patch
 
 from kombu.message import Message
 
