@@ -5,7 +5,8 @@ import sys
 
 from base64 import b64decode
 
-from case import call, mock, patch, skip
+from unittest.mock import call, patch
+from case import mock
 
 from kombu.exceptions import ContentDisallowed, EncodeError, DecodeError
 from kombu.serialization import (
@@ -17,6 +18,8 @@ from kombu.serialization import (
 )
 from kombu.utils.encoding import str_to_bytes
 
+import t.skip
+
 # For content_encoding tests
 unicode_string = 'abcdé\u8463'
 unicode_string_as_utf8 = unicode_string.encode('utf-8')
@@ -192,10 +195,10 @@ class test_Serialization:
         )
         assert a == b
 
-    @skip.if_pypy()
-    @skip.unless_module('msgpack', (ImportError, ValueError))
+    @t.skip.if_pypy
     def test_msgpack_loads(self):
         register_msgpack()
+        pytest.importorskip('msgpack')
         res = loads(msgpack_data,
                     content_type='application/x-msgpack',
                     content_encoding='binary')
@@ -207,9 +210,9 @@ class test_Serialization:
                     res[k] = [i.encode() for i in v]
         assert res == msgpack_py_data
 
-    @skip.if_pypy()
-    @skip.unless_module('msgpack', (ImportError, ValueError))
+    @t.skip.if_pypy
     def test_msgpack_dumps(self):
+        pytest.importorskip('msgpack')
         register_msgpack()
         a = loads(
             dumps(msgpack_py_data, serializer='msgpack')[-1],
@@ -223,16 +226,16 @@ class test_Serialization:
         )
         assert a == b
 
-    @skip.unless_module('yaml')
     def test_yaml_loads(self):
+        pytest.importorskip('yaml')
         register_yaml()
         assert loads(
             yaml_data,
             content_type='application/x-yaml',
             content_encoding='utf-8') == py_data
 
-    @skip.unless_module('yaml')
     def test_yaml_dumps(self):
+        pytest.importorskip('yaml')
         register_yaml()
         a = loads(
             dumps(py_data, serializer='yaml')[-1],
