@@ -12,14 +12,15 @@ import random
 import string
 from queue import Empty
 
-from botocore.exceptions import ClientError
-from case import Mock, skip
-from case.mock import patch
+from unittest.mock import Mock, patch
 
 from kombu import messaging
 from kombu import Connection, Exchange, Queue
 
-from kombu.transport import SQS
+boto3 = pytest.importorskip('boto3')
+
+from kombu.transport import SQS                 # noqa
+from botocore.exceptions import ClientError     # noqa
 
 SQS_Channel_sqs = SQS.Channel.sqs
 
@@ -126,7 +127,6 @@ class SQSClientMock:
                 q.messages = []
 
 
-@skip.unless_module('boto3')
 class test_Channel:
 
     def handleMessageCallback(self, message):
@@ -201,7 +201,6 @@ class test_Channel:
         assert self.queue_name in self.channel._queue_cache
 
     def test_region(self):
-        import boto3
         _environ = dict(os.environ)
 
         # when the region is unspecified
