@@ -1,11 +1,14 @@
 import pytest
 from queue import Empty
 
-from case import skip, patch
+from unittest.mock import patch
 from kombu import messaging
 from kombu import Connection, Exchange, Queue
+
 from kombu.transport import azureservicebus
 
+pytest.importorskip('azure.servicebus')
+
 try:
     # azure-servicebus version >= 0.50.0
     from azure.servicebus.control_client import Message, ServiceBusService
@@ -95,7 +98,6 @@ class AzureServiceBusClientMock:
             del queue
 
 
-@skip.unless_module('azure.servicebus')
 class test_Channel:
 
     def handleMessageCallback(self, message):
