@@ -1,12 +1,14 @@
 import pytest
+
 from queue import Empty
 
-from case import Mock, skip
+from unittest.mock import Mock
 
 from kombu.transport.consul import Channel, Transport
 
+pytest.importorskip('consul')
+
 
-@skip.unless_module('consul')
 class test_Consul:
 
     def setup(self):
