@@ -1,12 +1,14 @@
 import pytest
+
 from queue import Empty
 
-from case import Mock, patch, skip
+from unittest.mock import Mock, patch
 
 from kombu.transport.etcd import Channel, Transport
 
+pytest.importorskip('etcd')
+
 
-@skip.unless_module('etcd')
 class test_Etcd:
 
     def setup(self):
