@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import pytest
 import socket
 
@@ -148,7 +146,7 @@ class test_MemoryTransport:
         )
         message = consumer.queues[0].get()._raw
 
-        class Cycle(object):
+        class Cycle:
 
             def get(self, callback, timeout=None):
                 return (message, 'foo'), c1
