@@ -1,10 +1,10 @@
 import pytest
-from case import skip
 from kombu import Connection
 from kombu.transport import zookeeper
 
+pytest.importorskip('kazoo')
+
 
-@skip.unless_module('kazoo')
 class test_Channel:
     def setup(self):
         self.connection = self.create_connection()
